# Generated by `rjournal_article()` using `knitr::purl()`: do not edit by hand
# Please edit pencal-RJ.Rmd to modify this file

## ----cache = F----------------------------------------------------------------
library(pencal)
data(pbc2data)
ls(pbc2data)


## ----cache = F----------------------------------------------------------------
sdata = pbc2data$baselineInfo
ldata = pbc2data$longitudinalInfo


## ----cache = F----------------------------------------------------------------
head(sdata)


## ----cache = F----------------------------------------------------------------
head(ldata)


## ----cache = F----------------------------------------------------------------
# set the landmark time
lmark = 2


## ----cache = F----------------------------------------------------------------
# remove subjects who had event / were censored before landmark
sdata = subset(sdata, time > lmark)
ldata = subset(ldata, id %in% sdata$id)


## ----cache = F----------------------------------------------------------------
# remove measurements taken after landmark:
ldata = subset(ldata, fuptime <= lmark)


## ----cache = F----------------------------------------------------------------
# number of subjects retained in the analysis:
nrow(sdata)
# number of events (1s) and censored observations (0s):
table(sdata$event)


## ----kaplan, message=FALSE, cache = F, out.width='5in', fig.height=5.5, fig.align='center', fig.pos='htbp', fig.cap='Chart displaying the Kaplan-Meier estimates of the conditional survival probability $S(t | 2)$.'----
library(survival)
library(survminer)
surv.obj = Surv(time = sdata$time, event = sdata$event)
KM = survfit(surv.obj ~ 1, type = "kaplan-meier")
ggsurvplot(KM, data = sdata, risk.table = TRUE, cumevents = TRUE, legend = 'none')


## ----spaghetti, cache = F, out.width='5in', fig.align='center', fig.pos='htbp', fig.cap='Spaghetti and density charts  for the variable serBilir.'----
library(ggplot2)
library(gridExtra)
traj1 = ggplot(ldata, aes(x = age, y = serBilir, group = id)) + 
  geom_line(color = 'darkgreen') + theme_classic() + ggtitle('Trajectories of serBilir')
dens1 = ggplot(ldata, aes(x = serBilir)) + 
  geom_density(adjust=1.5, alpha=.4, fill = 'orange') + theme_classic() + 
  ggtitle('Density of serBilir')
grid.arrange(traj1, dens1, ncol = 2)


## ----cache = F----------------------------------------------------------------
ldata$logSerBilir = log(ldata$serBilir)
ldata$logSerChol = log(ldata$serChol)
ldata$logAlkaline = log(ldata$alkaline)
ldata$logSGOT = log(ldata$SGOT)
ldata$logProthrombin = log(ldata$prothrombin)


## ----cache = F----------------------------------------------------------------
lmms = fit_lmms(y.names = c('logSerBilir', 'logSerChol', 'albumin', 'logAlkaline',
                            'logSGOT', 'platelets', 'logProthrombin'), 
                fixefs = ~ age, ranefs = ~ age | id, t.from.base = fuptime,
                long.data = ldata, surv.data = sdata, n.boots = 0, n.cores = 8, 
                verbose = FALSE)


## ----cache = F----------------------------------------------------------------
summary(lmms, yname = 'albumin', what = 'betas')
summary(lmms, yname = 'albumin', what = 'variances')


## ----cache = F----------------------------------------------------------------
summary(lmms, yname = 'albumin', what = 'tTable')


## ----cache = F----------------------------------------------------------------
pred_ranefs = summarize_lmms(object = lmms, n.cores = 8, verbose = FALSE)
summary(pred_ranefs)


## ----cache = F----------------------------------------------------------------
round(pred_ranefs$ranef.orig[1:4, 1:4], 4)


## ----cache = F----------------------------------------------------------------
pencox = fit_prclmm(object = pred_ranefs, surv.data = sdata,
                    baseline.covs = ~ baselineAge + sex + treatment, penalty = 'ridge', 
                    standardize = TRUE, n.cores = 8, verbose = FALSE)


## ----cache = F----------------------------------------------------------------
summary(pencox)


## ----cache = F----------------------------------------------------------------
step3summary = summary(pencox)
ls(step3summary)
step3summary$coefficients


## ----cache = F----------------------------------------------------------------
preds = survpred_prclmm(step1 = lmms, step2 = pred_ranefs, step3 = pencox, times = 3:7)


## ----cache = F----------------------------------------------------------------
ls(preds)
head(preds$predicted_survival)


## ----survplot, fig.height=3.8, fig.width=5, cache=TRUE, fig.cap="Predicted survival probabilities $\\hat{S}_i(t | 2), \\:t \\in [2, 12]$ for subjects $i \\in \\{54, 111, 173, 271\\}$."----
survplot_prc(step1 = lmms, step2 = pred_ranefs, step3 = pencox, 
             ids = c(54, 111, 173, 271), tmax = 12)


## ----cache = F----------------------------------------------------------------
new_ldata = subset(ldata, id %in% c(5, 54, 110))
new_sdata = subset(sdata, id %in% c(5, 54, 110), c('id', 'baselineAge', 'sex', 'treatment'))
head(new_ldata)
head(new_sdata)


## ----cache = F----------------------------------------------------------------
pred_new = survpred_prclmm(step1 = lmms, step2 = pred_ranefs, step3 = pencox, times = 3:7,
                           new.longdata = new_ldata, new.basecovs = new_sdata)
pred_new$predicted_survival


## ----cache = F----------------------------------------------------------------
# naive performance (biased, optimistic estimate)
naive_perf = performance_prc(step2 = pred_ranefs, step3 = pencox, metric = 'tdauc',
                             times = 3:7, n.cores = 8, verbose = FALSE)


## ----cache = F----------------------------------------------------------------
naive_perf


## ----cbocp1, cache = F--------------------------------------------------------
step1 = fit_lmms(y.names = c('logSerBilir', 'logSerChol', 'albumin', 'logAlkaline',
                             'logSGOT', 'platelets', 'logProthrombin'), 
                fixefs = ~ age, ranefs = ~ age | id, t.from.base = fuptime,
                long.data = ldata, surv.data = sdata, n.boots = 50, n.cores = 8, 
                verbose = FALSE)
step2 = summarize_lmms(object = step1, n.cores = 8, verbose = FALSE)
step3 = fit_prclmm(object = step2, surv.data = sdata,
                   baseline.covs = ~ baselineAge + sex + treatment,
                   penalty = 'ridge', n.cores = 8, verbose = FALSE)


## ----cbocp2, message = F, cache = F-------------------------------------------
# bootstrap-corrected performance (unbiased estimate)
cbocp = performance_prc(step2 = step2, step3 =  step3, metric = c('tdauc', 'brier'), 
                        times = 3:7, n.cores = 8, verbose = FALSE)
cbocp


## ----ctime1, echo=FALSE, fig.cap='Left and center: average computing time (in seconds) of the estimation of the PRC LMM model as a function of the sample size $n$ (simulation 1, left) and of the number of longitudinal predictors $p$ (simulation 2, center). Right: average computing time (in minutes) for the computation of the CBOCP as a function of $B$ (simulation 3).', out.width='5.5in', fig.align='center', fig.pos='htbp'----
knitr::include_graphics('comptime_sims_123.png')


## ----ctime4, echo=FALSE, fig.cap='Average computing time (in seconds) for the estimation of the PRC LMM model and the computation of the CBOCP as a function of the number of cores.', out.width='4.5in', fig.align='center', fig.pos='htbp'----
knitr::include_graphics('comptime_sim4b.png')

